<?php
	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly.
	}

	if ( ! class_exists( 'WP_List_Table' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
	}

	class ZLEADSCRM_PIPELINE_Core_Pipelines extends WP_List_Table {

		public function __construct() {
			parent::__construct(
				array(
					'singular' => 'pipeline',
					'plural'   => 'pipelines',
					'ajax'     => false,
				)
			);
		}

		public function print_overview() {
			$this->prepare_items();
			echo '<div class="zleadscrm_overview_wrap">';
			echo '<h2 class="screen-reader-text">Pipeline</h2>';
			if ( count( $this->items ) != 0 ) {
				$this->display();
			} else {
				echo '<div style="color:#000; padding:1px 12px; background: #fff; border-left: solid 4px #ffb900;">';
				echo '<p style="margin: .5em 0; padding: 2px;">No Pipelines</p>';
				echo '</div>';
			}
			echo '</div>';
		}

		public function column_default( $result, $column_name ) {
			switch ( $column_name ) {
				case 'title':
					return '<span>' . $result['title'] . '</span>';
				case 'shortcode':
					return '<span>' . $result['shortcode'] . '</span>';
				case 'author':
					return '<span>' . $result['author'] . '</span>';
				case 'date':
					return '<span>' . $result['date'] . '</span>';
				case 'actions':
					ob_start();
					?><p>
					<?php

					$actions['edit'] = array(
						'url'    => admin_url( 'admin.php' ) . '?page=zleadscrm_pipelines&edit_pipeline=' . $result['id'],
						'class'  => 'edit',
						'target' => '_self'
					);

					foreach ( $actions as $action ) {
						printf( '<a class="button tips dashicons dashicons-%s" href="%s" target="%s" style="width: 40px;"></a>', esc_attr( $action['class'] ), esc_url( $action['url'] ), esc_attr( $action['target'] ) );
					}
					?>
                    </p>
					<?php
					$result_actions = ob_get_contents();
					ob_end_clean();

					return $result_actions;
			}

			return '';
		}

		public function display_tablenav( $which ) {
			if ( $which == 'top' ) {
				echo '<div class="alignright" style="margin-bottom: 1rem;">';
				$this->pagination( 'top' );
				echo '</div>';
			}
		}

		public function get_columns() {
			$columns = array(
				'title'     => 'Title',
				'shortcode' => 'Shortcode',
				'author'    => 'Author',
				'date'      => 'Date',
				'actions'   => 'Actions'
			);

			return $columns;
		}

		public function prepare_items() {
			$current_page = $this->get_pagenum();
			$per_page     = 20;
			$offset       = $current_page != 0 ? ( $current_page - 1 ) * $per_page : 0;

			/**
			 * Init column headers.
			 */
			$this->_column_headers = array( $this->get_columns(), array(), array() );

			$results = get_posts( array(
				'post_type' => 'zleadscrm_pipeline',
				'number'    => $per_page,
				'offset'    => $offset
			) );

			$items = [];

			foreach ( $results as $result ) {
				$item['id']        = $result->ID;
				$item['title']     = $result->post_title;
				$shortcode_id      = get_post_meta( $result->ID, 'pipeline_shortcode_id', true );
				$item['shortcode'] = '[pipeline-form id="' . $shortcode_id . '" title="' . $result->post_title . '"]';
				$item['author']    = get_user_by( 'id', $result->post_author )->display_name;
				$item['date']      = date_format( date_create( $result->post_date ), get_option( 'date_format' ) );

				array_push( $items, $item );
			}

			$this->items = $items;


			/**
			 * Pagination.
			 */

			$total_results = $this->get_total_number_of_results();

			$this->set_pagination_args(
				array(
					'total_items' => $total_results,
					'per_page'    => $per_page,
					'total_pages' => ceil( $total_results / $per_page ),
				)
			);
		}


		public function get_total_number_of_results() {
			$results = get_posts( array(
				'post_type' => 'zleadscrm_pipeline'
			) );

			return count( $results );
		}

	}

?>